MethodChannelSumupSdkWrapper class

An implementation of SumupSdkWrapperPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
isCheckoutInProgress Future<bool?>
no setterinherited
isTipOnCardReaderAvailable Future<bool>
no setteroverride
merchant Future<SumupPluginMerchantResponse>
no setteroverride
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkout(SumupPaymentRequest paymentRequest) Future<SumupPluginCheckoutResponse>
override
getPlatformVersion() Future<String?>
override
init(String affiliateKey) Future<SumupPluginResponse>
override
isLoggedIn() Future<bool?>
override
login() Future<SumupPluginResponse>
override
loginWithToken(String token) Future<SumupPluginResponse>
override
logout() Future<SumupPluginResponse>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openSettings() Future<SumupPluginResponse>
override
prepareForCheckout() Future<SumupPluginResponse>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited