SumupSdkWrapperPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- SumupSdkWrapperPlatform
- Implementers
Constructors
- SumupSdkWrapperPlatform()
- Constructs a SumupSdkWrapperPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isCheckoutInProgress
→ Future<
bool?> -
no setter
-
isTipOnCardReaderAvailable
→ Future<
bool> -
no setter
-
merchant
→ Future<
SumupPluginMerchantResponse> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkout(
SumupPaymentRequest paymentRequest) → Future< SumupPluginCheckoutResponse> -
getPlatformVersion(
) → Future< String?> -
init(
String affiliateKey) → Future< SumupPluginResponse> -
isLoggedIn(
) → Future< bool?> -
login(
) → Future< SumupPluginResponse> -
loginWithToken(
String token) → Future< SumupPluginResponse> -
logout(
) → Future< SumupPluginResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openSettings(
) → Future< SumupPluginResponse> -
prepareForCheckout(
) → Future< SumupPluginResponse> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ SumupSdkWrapperPlatform
-
The default instance of SumupSdkWrapperPlatform to use.
getter/setter pair